#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# === ChemistryParadise::ParseCommandline
# =========================================================================== #
# require 'chemistry_paradise/commandline/menu.rb'
# =========================================================================== #
require 'chemistry_paradise/base/base.rb'
require 'chemistry_paradise/toplevel_methods/display_where_the_molmasses_are_kept.rb'
require 'chemistry_paradise/toplevel_methods/show_electron_negativity_chart.rb'
require 'chemistry_paradise/show_electron_negativity_of_this_element.rb'

module ChemistryParadise

class ParseCommandline < ::ChemistryParadise::Base # === ChemistryParadise::ParseCommandline

  # ========================================================================= #
  # === menu                                                       (menu tag)
  # ========================================================================= #
  def menu(
      i = @commandline
    )
    if i.is_a? Array
      i.each {|entry| menu(entry) }
    else
      case i
      # ===================================================================== #
      # === chemistry_paradise --periodic-table
      # ===================================================================== #
      when /^-?-?periodic(_|-)?table$/i
        show_the_periodic_table
        exit
      # ===================================================================== #
      # === chemistry_paradise --electronegativity-of=F/Fe
      # ===================================================================== #
      when /-?-?electronegativity(_|-)?of=(.+)/
        these_elements = $2.to_s.dup.strip
        if these_elements.include? '/'
          these_elements = these_elements.split('/')
        end
        ChemistryParadise::ShowElectronNegativityOfThisElement.new(these_elements)
      # ===================================================================== #
      # === chemistry_paradise show_electron_negativity_chart
      # ===================================================================== #
      when /show(_|-)?electron(_|-)?negativity(_|-)?chart/
        show_electron_negativity_chart
      # ===================================================================== #
      # === chemistry_paradise test_which_molecules?
      # ===================================================================== #
      when /test(_|-)?which(_|-)?molecules\??/
        pp ARRAY_TEST_THESE_MOLECULES
      # ===================================================================== #
      # === chemistry_paradise --molmassen?
      # ===================================================================== #
      when /molmassen\??/,
           /display(_|-)?molmassen(_|-)?file/,
           /display(_|-)?where(_|-)?the(_|-)?molmasses(_|-)?are(_|-)?kept/
        ::ChemistryParadise.display_where_the_molmasses_are_kept
      # ===================================================================== #
      # === chemistry_paradise --help
      # ===================================================================== #
      when /^-?-?help/
        show_help
      else
        if i.start_with?('/') and i.end_with?('/')
          # ================================================================= #
          # Assume this to be a pseudo-regex.
          # ================================================================= #
          search_for_this_element = i.delete('/').capitalize
          _ = ChemistryParadise.return_element_symbol_from_this_german_name(search_for_this_element)
          if _
            e simp(search_for_this_element)+' corresponds to '+sfancy(_)+'.'
          end
        end
      end
    end
  end; alias check_against_menu menu # === check_against_menu

end; end