#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# === ChemistryParadise::ParseCommandline
#
# Use this class in order to parse the commandline.
# =========================================================================== #
# require 'chemistry_paradise/commandline/parse_commandline.rb'
# =========================================================================== #
require 'chemistry_paradise/base/base.rb'
require 'chemistry_paradise/commandline/menu.rb'
require 'chemistry_paradise/commandline/help.rb'

module ChemistryParadise

class ParseCommandline < ::ChemistryParadise::Base # === ChemistryParadise::ParseCommandline

  # ========================================================================= #
  # === initialize
  # ========================================================================= #
  def initialize(
      optional_input = ARGV,
      run_already    = true
    )
    set_commandline(optional_input)
    reset
    run if run_already
  end

  # ========================================================================= #
  # === reset
  # ========================================================================= #
  def reset
    super()
  end

  # ========================================================================= #
  # === show_the_periodic_table
  # ========================================================================= #
  def show_the_periodic_table
    _ = ::ChemistryParadise.periodic_table?
    if File.exist? _
      YAML.load_file(_).each_pair {|key, value|
        e '  '+(key.to_s+ ':').ljust(3)+' '+value.to_s.rjust(2)
      }
    end
  end

  # ========================================================================= #
  # === set_commandline
  # ========================================================================= #
  def set_commandline(i)
    i = [i] unless i.is_a? Array
    @commandline = i
  end

  # ========================================================================= #
  # === run
  # ========================================================================= #
  def run
    menu
  end

  # ========================================================================= #
  # === berechne_atomgewicht
  # ========================================================================= #
  def berechne_atomgewicht(i)
    pp i
    if i.is_a? Array
      i.flatten.each {|entry|
        berechne_atomgewicht(i)
      }
    else
      if i == :test_default_molecules
        i = ARRAY_TEST_THESE_MOLECULES
      end
      if i.is_a? Array
        berechne_atomgewicht(i)
      else
        e sprintf(
          'The mass number of %-4s is %3s',
          i,
          ChemistryParadise::CalculateAtomicMass.new(i).result.to_s
        )
      end
    end
  end

end; end

if __FILE__ == $PROGRAM_NAME
  ChemistryParadise::ParseCommandline.new(ARGV)
end