#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# require 'chemistry_paradise/constants/constants.rb'
# =========================================================================== #
require 'yaml'
require 'chemistry_paradise/constants/file_constants.rb'

module ChemistryParadise

module Constants # include ChemistryParadise::Constants

  # ========================================================================= #
  # === N
  # ========================================================================= #
  N = "\n"

  # ========================================================================= #
  # === ELECTRON_NEGATIVITY_CHART
  # ========================================================================= #
  if File.exist? FILE_ELECTRON_NEGATIVITY_CHART
    ELECTRON_NEGATIVITY_CHART = YAML.load_file(FILE_ELECTRON_NEGATIVITY_CHART)
  else
    ELECTRON_NEGATIVITY_CHART = nil
  end

  # ========================================================================= #
  # === electron_negativity_chart?
  # ========================================================================= #
  def electron_negativity_chart?
    ELECTRON_NEGATIVITY_CHART
  end

  # ========================================================================= #
  # === SPEED_OF_LIGHT
  #
  # The speed of light, in m / sec.
  #
  # You can refer to this constant in your ruby scripts too:
  #   c = ChemistryParadise::Constants::SPEED_OF_LIGHT
  # ========================================================================= #
  SPEED_OF_LIGHT = 299_792_458

  # ========================================================================= #
  # === PLANK_CONSTANT
  #
  #   h = ChemistryParadise::Constants::PLANK_CONSTANT
  # ========================================================================= #
  PLANK_CONSTANT = 6.62607004 * (10 ** -34)

end; end