#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# require 'chemistry_paradise/constants/german_names_of_elements_to_element_symbol.rb'
# =========================================================================== #
# This .rb file will translate from the german name of an element towards
# the element symbol, if applicable. So, "Quecksilber" will become
# "Hg".
#
# See: https://de.wikipedia.org/wiki/Liste_der_chemischen_Elemente
# =========================================================================== #
module ChemistryParadise

  # ========================================================================= #
  # === ChemistryParadise::GERMAN_NAMES_OF_ELEMENTS_TO_ELEMENT_SYMBOL
  # ========================================================================= #
  GERMAN_NAMES_OF_ELEMENTS_TO_ELEMENT_SYMBOL = {
    'Actinium'      => 'Ac',
    'Aluminium'     => 'Al',
    'Americium'     => 'Am',
    'Antimon'       => 'Sb',
    'Argon'         => 'Ar',
    'Arsen'         => 'As',
    'Astat'         => 'At',
    'Barium'        => 'Ba',
    'Berkelium'     => 'Bk',
    'Beryllium'     => 'Be',
    'Bismut'        => 'Bi',
    'Blei'          => 'Pb',
    'Bohrium'       => 'Bh',
    'Bor'           => 'B',
    'Brom'          => 'Br',
    'Cadmium'       => 'Cd',
    'Caesium'       => 'Cs',
    'Calcium'       => 'Ca',
    'Californium'   => 'Cf',
    'Cer'           => 'Ce',
    'Chlor'         => 'Cl',
    'Chrom'         => 'Cr',
    'Cobalt'        => 'Co',
    'Copernicium'   => 'Cn',
    'Curium'        => 'Cm',
    'Darmstadtium'  => 'Ds',
    'Dubnium'       => 'Db',
    'Dysprosium'    => 'Dy',
    'Einsteinium'   => 'Es',
    'Eisen'         => 'Fe',
    'Erbium'        => 'Er',
    'Europium'      => 'Eu',
    'Fermium'       => 'Fm',
    'Flerovium'     => 'Fl',
    'Fluor'         => 'F',
    'Francium'      => 'Fr',
    'Gadolinium'    => 'Gd',
    'Gallium'       => 'Ga',
    'Germanium'     => 'Ge',
    'Gold'          => 'Au',
    'Hafnium'       => 'Hf',
    'Hassium'       => 'Hs',
    'Helium'        => 'He',
    'Holmium'       => 'Ho',
    'Indium'        => 'In',
    'Iod'           => 'I',
    'Iridium'       => 'Ir ',
    'Kalium'        => 'K',
    'Kohlenstoff'   => 'C',
    'Krypton'       => 'Kr',
    'Kupfer'        => 'Cu',
    'Lanthan'       => 'La',
    'Lawrencium'    => 'Lr',
    'Lithium'       => 'Li',
    'Livermorium'   => 'Lv',
    'Lutetium'      => 'Lu',
    'Magnesium'     => 'Mg',
    'Mangan'        => 'Mn',
    'Meitnerium'    => 'Mt',
    'Mendelevium'   => 'Md',
    'Molybdän'      => 'Mo',
    'Moscovium'     => 'Mc',
    'Natrium'       => 'Na',
    'Neodym'        => 'Nd',
    'Neon'          => 'Ne',
    'Neptunium'     => 'Np',
    'Nickel'        => 'Ni',
    'Nihonium'      => 'Nh',
    'Niob'          => 'Nb',
    'Nobelium'      => 'No',
    'Oganesson'     => 'Og',
    'Osmium'        => 'Os',
    'Palladium'     => 'Pd',
    'Phosphor'      => 'P',
    'Platin'        => 'Pt',
    'Plutonium'     => 'Pu',
    'Polonium'      => 'Po',
    'Praseodym'     => 'Pr',
    'Promethium'    => 'Pm',
    'Protactinium'  => 'Pa',
    'Quecksilber'   => 'Hg',
    'Radium'        => 'Ra',
    'Radon'         => 'Rn',
    'Rhenium'       => 'Re',
    'Rhodium'       => 'Rh',
    'Roentgenium'   => 'Rg',
    'Rubidium'      => 'Rb',
    'Ruthenium'     => 'Ru',
    'Rutherfordium' => 'Rf',
    'Samarium'      => 'Sm',
    'Sauerstoff'    => 'O',
    'Scandium'      => 'Sc',
    'Schwefel'      => 'S',
    'Seaborgium'    => 'Sg',
    'Selen'         => 'Se',
    'Silber'        => 'Ag',
    'Silicium'      => 'Si',
    'Stickstoff'    => 'N',
    'Strontium'     => 'Sr',
    'Tantal'        => 'Ta',
    'Technetium'    => 'Tc',
    'Tellur'        => 'Te',
    'Tenness'       => 'Ts',
    'Terbium'       => 'Tb',
    'Thallium'      => 'Tl',
    'Thorium'       => 'Th',
    'Thulium'       => 'Tm',
    'Titan'         => 'Ti',
    'Uran'          => 'U',
    'Vanadium'      => 'V',
    'Wasserstoff'   => 'H',
    'Wolfram'       => 'W',
    'Xenon'         => 'Xe',
    'Ytterbium'     => 'Yb',
    'Yttrium'       => 'Y',
    'Zink'          => 'Zn',
    'Zinn'          => 'Sn',
    'Zirconium'     => 'Zr'
  }

  # ========================================================================= #
  # === ChemistryParadise.return_element_symbol_from_this_german_name
  # ========================================================================= #
  def self.return_element_symbol_from_this_german_name(i)
    i = i.dup if i.frozen?
    i.capitalize!
    if GERMAN_NAMES_OF_ELEMENTS_TO_ELEMENT_SYMBOL.has_key? i
      GERMAN_NAMES_OF_ELEMENTS_TO_ELEMENT_SYMBOL[i]
    else
      nil
    end
  end

end

if __FILE__ == $PROGRAM_NAME
  puts ChemistryParadise::GERMAN_NAMES_OF_ELEMENTS_TO_ELEMENT_SYMBOL['Quecksilber']
  puts ChemistryParadise.return_element_symbol_from_this_german_name('quecksilber')
end