#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# === CelsiusToFahrenheit
#
# Celsius was defined by the freezing point of water (and later the melting
# point of ice). Nowadays, the Celsius scale is a derived scale, defined in
# relation to the Kelvin temperature scale.
#
# Zero on the Celsius scale (0C) is defined as the equivalent to 273.15 K.
# 
# The Celsius scale is an interval system but not a ratio system, meaning
# it follows a relative scale but not an absolute scale. 
#
# A temperature difference of 1 deg C is the equivalent of a temperature
# difference 1.8F (which is 9/5).
#
# Usage example:
#   CelsiusToFahrenheit.new
# =========================================================================== #
require 'colours'
require 'opn'
require 'chemistry_paradise/converters/shared.rb'

module ChemistryParadise

class CelsiusToFahrenheit # require 'celsius_to_fahrenheit'; CelsiusToFahrenheit.new

  include Colours
  include ChemistryParadise::Converters

  # ========================================================================= #
  # === NAMESPACE
  # ========================================================================= #
  NAMESPACE = 'ChemistryParadise::CelsiusToFahrenheit'

  # ========================================================================= #
  # === initialize
  # ========================================================================= #
  def initialize(
      celsius     = 0,
      run_already = true
    )
    reset
    set_celsius(celsius)
    run if run_already
  end

  # ========================================================================= #
  # === reset                                                     (reset tag)
  # ========================================================================= #
  def reset
    set_celsius
  end

  # ========================================================================= #
  # === set_celsius
  # ========================================================================= #
  def set_celsius(i = 0)
    i = i.first if i.is_a? Array
    i = i.to_s.dup
    i = i.to_f
    @celsius = i
  end

  # ========================================================================= #
  # === do_the_calculation
  #
  # We determine how many Fahrenheit we have here, by using the
  # specific formula.
  # ========================================================================= #
  def do_the_calculation
    @fahrenheit = (@celsius * CELSIUS_TO_FAHRENHEIT_CONVERSION_FACTOR)+32.00
  end

  # ========================================================================= #
  # === fahrenheit?
  # ========================================================================= #
  def fahrenheit?
    @fahrenheit
  end; alias n_fahrenheit fahrenheit? # === fahrenheit?

  # ========================================================================= #
  # === input?
  # ========================================================================= #
  def celsius?
    @celsius
  end; alias n_celsius celsius? # === n_celsius

  # ========================================================================= #
  # === run                                                         (run tag)
  # ========================================================================= #
  def run
    do_the_calculation
  end

  # ========================================================================= #
  # === report_result
  # ========================================================================= #
  def report_result
    opnn if use_opn?
    e n_celsius.to_s+' '+simp('Celsius')+' are '+n_fahrenheit.to_s+
      ' '+simp('Fahrenheit')+'.'
  end; alias report report_result # === report

  # ========================================================================= #
  # === use_opn?
  # ========================================================================= #
  def use_opn?
    false
  end

  # ========================================================================= #
  # === opnn
  # ========================================================================= #
  def opnn
    Opn.opn(use_this_as_namespace: NAMESPACE)
  end

  # ========================================================================= #
  # === CelsiusToFahrenheit[]
  # ========================================================================= #
  def self.[](i)
    _ = CelsiusToFahrenheit.new(i)
    _.report
  end

end; end

if __FILE__ == $PROGRAM_NAME
  _ = ChemistryParadise::CelsiusToFahrenheit.new(ARGV)
  _.report_result
end # celsius_to_fahrenheit2 50