#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# === ChemistryParadise::FahrenheitToCelsius
#
# Usage example:
#   ChemistryParadise::FahrenheitToCelsius.new
# =========================================================================== #
require 'colours'
require 'opn'
require 'chemistry_paradise/converters/shared.rb'

module ChemistryParadise

class FahrenheitToCelsius

  include Colours
  include ChemistryParadise::Converters

  # ========================================================================= #
  # === NAMESPACE
  # ========================================================================= #
  NAMESPACE = 'ChemistryParadise::FahrenheitToCelsius'

  # ========================================================================= #
  # === initialize
  # ========================================================================= #
  def initialize(
      fahrenheit  = 0,
      run_already = true
    )
    reset
    set_fahrenheit(fahrenheit)
    run if run_already
  end

  # ========================================================================= #
  # === reset                                                     (reset tag)
  # ========================================================================= #
  def reset
    set_fahrenheit
  end

  # ========================================================================= #
  # === set_fahrenheit
  # ========================================================================= #
  def set_fahrenheit(i = 0)
    i = i.first if i.is_a? Array
    i = i.to_s.dup
    i = i.to_f
    @fahrenheit = i
  end

  # ========================================================================= #
  # === do_the_calculation
  #
  # We determine how many Fahrenheit we have here, by using the
  # specific formula.
  # ========================================================================= #
  def do_the_calculation
    @celsius = (@fahrenheit - 32) / FAHRENHEIT_TO_CELSIUS_CONVERSION_FACTOR
  end

  # ========================================================================= #
  # === fahrenheit?
  # ========================================================================= #
  def fahrenheit?
    @fahrenheit
  end; alias n_fahrenheit fahrenheit? # === fahrenheit?

  # ========================================================================= #
  # === input?
  # ========================================================================= #
  def celsius?
    @celsius
  end; alias n_celsius celsius? # === n_celsius

  # ========================================================================= #
  # === run                                                         (run tag)
  # ========================================================================= #
  def run
    do_the_calculation
  end

  # ========================================================================= #
  # === report_result
  # ========================================================================= #
  def report_result
    opnn if use_opn?
    e n_fahrenheit.to_s+' '+simp('Fahrenheit')+' are '+n_celsius.round(2).to_s+
      ' '+simp('Celsius')+'.'
  end; alias report report_result # === report

  # ========================================================================= #
  # === use_opn?
  # ========================================================================= #
  def use_opn?
    false
  end

  # ========================================================================= #
  # === opnn
  # ========================================================================= #
  def opnn
    Opn.opn(use_this_as_namespace: NAMESPACE)
  end

  # ========================================================================= #
  # === FahrenheitToCelsius[]
  # ========================================================================= #
  def self.[](i)
    _ = FahrenheitToCelsius.new(i)
    _.report
  end

end; end

if __FILE__ == $PROGRAM_NAME
  _ = ChemistryParadise::FahrenheitToCelsius.new(ARGV)
  _.report_result
end # fahrenheit_to_celsius2 50