#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# === ChemistryParadise::ElectronNegativityChart
#
# This class will tell us about the individual electron negativity of a
# given element at hand.
# =========================================================================== #
require 'chemistry_paradise/base/base.rb'

module ChemistryParadise

class ElectronNegativityChart < Base

  # ========================================================================= #
  # === initialize
  # ========================================================================= #
  def initialize(
      optional_input = nil,
      run_already    = true
    )
    set_input(optional_input)
    run if run_already
  end

  # ========================================================================= #
  # === set_input
  # ========================================================================= #
  def set_input(i)
    @input = i
  end

  # ========================================================================= #
  # === show_chart
  #
  # Show the particular electronegativy chart for that element.
  # ========================================================================= #
  def show_chart
    # ======================================================================= #
    # Tap into the elctron negativity chart next.
    # ======================================================================= #
    electron_negativity_chart?.each_pair {|key, value|
      e "#{key.ljust(2)} -> #{value.to_s}"
    }
  end

  # ========================================================================= #
  # === entry?
  # ========================================================================= #
  def entry?
    @input.first
  end

  # ========================================================================= #
  # === ElectronNegativityChart.show_chart
  # ========================================================================= #
  def self.show
    ElectronNegativityChart.new.show_chart
  end

  # ========================================================================= #
  # === run
  # ========================================================================= #
  def run
    if @input.nil?
      show_chart
    else
      e electron_negativity_chart?[entry?]
    end
  end

end; end

if __FILE__ == $PROGRAM_NAME
  include ChemistryParadise
  ElectronNegativityChart.new(ARGV)
end # echart P