#!/usr/bin/ruby -w
# Encoding: UTF-8
# =========================================================================== #
# === ChemistryParadise::EquationSolver
#
# Usage example:
#   ChemistryParadise::EquationSolver.new
# =========================================================================== #
require 'chemistry_paradise/base/base.rb'
require 'chemistry_paradise/split_molecule_names.rb'

module ChemistryParadise

class EquationSolver < ::ChemistryParadise::Base # require 'equation_solver'; EquationSolver.new

  # ========================================================================= #
  # === THIS_FORMULA
  # ========================================================================= #
  THIS_FORMULA = 'NH3HHH + O2 -> N2 + H2O'

  # ========================================================================= #
  # === TOKEN_TO_SPLIT_AT
  # ========================================================================= #
  TOKEN_TO_SPLIT_AT = '->'

  # ========================================================================= #
  # === initialize
  # ========================================================================= #
  def initialize(
      i           = nil,
      run_already = true
    )
    reset
    set_input(i)
    run if run_already
  end

  # ========================================================================= #
  # === reset
  # ========================================================================= #
  def reset # (reset tag)
    @token_to_split_at = TOKEN_TO_SPLIT_AT
  end

  # ========================================================================= #
  # === set_input
  # ========================================================================= #
  def set_input(i = '')
    i = i.first if i.is_a? Array
    i = THIS_FORMULA if i.nil?
    i = i.to_s.dup
    i.strip!
    # ======================================================================= #
    # Next, we will get rid of all ' '.
    # ======================================================================= #
    i.tr!(' ','')
    @input = i
  end

  # ========================================================================= #
  # === left?
  # ========================================================================= #
  def left?
    @left_hand_side
  end

  # ========================================================================= #
  # === right?
  # ========================================================================= #
  def right?
    @right_hand_side
  end

  # ========================================================================= #
  # === ensure_that_the_token_is_correct
  # ========================================================================= #
  def ensure_that_the_token_is_correct
    if @input.include? '=' # In this case we overrule the token.
      @token_to_split_at = '='
    end
  end

  # ========================================================================= #
  # === split_into_components
  # ========================================================================= #
  def split_into_components
    @left_hand_side, @right_hand_side = @input.
      split(@token_to_split_at).map(&:strip)
    # ======================================================================= #
    # Ok, we now have our left side, and we have our right side.
    # We will next get the total content of Elements at the left
    # and at the right side.
    # ======================================================================= #
    p SplitMoleculeNames.new left?
    p SplitMoleculeNames.new right?
    if are_both_sides_equal?
      opn; e 'Both sides are now equal.'
    else
      opn; e 'Both sides are not equal.'
    end
  end

  # ========================================================================= #
  # === are_both_sides_equal?
  # ========================================================================= #
  def are_both_sides_equal?
    result = false
    # ======================================================================= #
    # We have to eliminate the '+' characters.
    # ======================================================================= #
    left  = SplitMoleculeNames.new(left?.delete('+')).total?
    right = SplitMoleculeNames.new(right?.delete('+')).total?
    result = ( left == right )
    return result
  end

  # ========================================================================= #
  # === run
  # ========================================================================= #
  def run # (run tag)
    ensure_that_the_token_is_correct
    split_into_components
  end

end; end

if __FILE__ == $PROGRAM_NAME
  ChemistryParadise::EquationSolver.new(ARGV)
end # equation_solver
    # equation_solver '2 Fe + 3 Cl2 = FeCl3'