#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# === ChemistryParadise::ShowElectronNegativityOfThisElement
#
# This class will report the electron negativity of the input-element,
# such as "S" or "Fe" and so forth (chemical elements).
#
# Usage example in ruby:
#   Chemistry::ShowElectronNegativityOfThisElement.new
# =========================================================================== #
# require 'chemistry_paradise/show_electron_negativity_of_this_element.rb'
# =========================================================================== #
require 'chemistry_paradise/base/base.rb'

module ChemistryParadise

class ShowElectronNegativityOfThisElement < Base # === ChemistryParadise::ShowElectronNegativityOfThisElement.new

  # ========================================================================= #
  # === NAMESPACE
  # ========================================================================= #
  NAMESPACE = inspect

  # ========================================================================= #
  # === initialize
  # ========================================================================= #
  def initialize(
      i           = nil,
      run_already = true
    )
    reset
    set_input(i)
    run if run_already
  end

  # ========================================================================= #
  # === reset                                                     (reset tag)
  # ========================================================================= #
  def reset
    super()
    @dataset = Constants::ELECTRON_NEGATIVITY_CHART
  end

  # ========================================================================= #
  # === set_input
  # ========================================================================= #
  def set_input(i = '')
    i = [i] unless i.is_a? Array
    @input = i
  end

  # ========================================================================= #
  # === input?
  # ========================================================================= #
  def input?
    @input
  end

  # ========================================================================= #
  # === run                                                         (run tag)
  # ========================================================================= #
  def run
    try_to_detect_the_electron_negativity_of_the_passed_elements
  end

  # ========================================================================= #
  # === try_to_detect_the_electron_negativity_of_the_passed_elements
  # ========================================================================= #
  def try_to_detect_the_electron_negativity_of_the_passed_elements
    dataset = @dataset
    input?.each {|this_element|
      if dataset.has_key? this_element
        electron_negativity_value = dataset[this_element]
        e "#{simp(this_element.ljust(2))} has an electron negativity of "\
          "#{sfancy(electron_negativity_value)}"\
          " (in this Pauling electronegativity scale)"
      end
    }
  end

  # ========================================================================= #
  # === opnn
  # ========================================================================= #
  def opnn
    super(NAMESPACE)
  end

  # ========================================================================= #
  # === []
  # ========================================================================= #
  def self.[](i = '')
    self.new(i)
  end

end; end

if __FILE__ == $PROGRAM_NAME
  ChemistryParadise::ShowElectronNegativityOfThisElement.new(ARGV)
end # show_electron_negativity_of_this_element S