#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# === ChemistryParadise::ShowElement
#
# Input should be something like this:
#
#   show_element 'Xe+5'
#
# Usage example:
#   ChemistryParadise::ShowElement.new
# =========================================================================== #
require 'chemistry_paradise/base/base.rb'

module ChemistryParadise

class ShowElement < ::ChemistryParadise::Base # require 'show_element'; ShowElement.new

  # ========================================================================= #
  # === NAMESPACE
  # ========================================================================= #
  NAMESPACE = inspect

  # ========================================================================= #
  # === PERIODIC_TABLE
  # ========================================================================= #
  PERIODIC_TABLE = YAML.load_file(ChemistryParadise::Shared.periodic_table?)

  # ========================================================================= #
  # === initialize
  # ========================================================================= #
  def initialize(
      i           = nil,
      run_already = true
    )
    reset
    set_input(i)
    run if run_already
  end

  # ========================================================================= #
  # === reset
  # ========================================================================= #
  def reset # (reset tag)
    set_name_of_the_element
    set_relative_position
  end

  # ========================================================================= #
  # === set_input
  # ========================================================================= #
  def set_input(i = '')
    i = i.first if i.is_a? Array
    i = i.to_s.dup if i
    @input = i
    process_input
  end

  # ========================================================================= #
  # === set_relative_position
  # ========================================================================= #
  def set_relative_position(i = 0)
    i = i.to_i if i
    @relative_position = i
  end

  # ========================================================================= #
  # === process_input
  # ========================================================================= #
  def process_input
    if    @input.include? '+'
      set_batch('+')
    elsif @input.include? '-'
      set_batch('-')
    else
      set_name_of_the_element(@input)
    end
  end

  # ========================================================================= #
  # === set_batch
  #
  # This will set both (1) the name and (2) the relative position.
  # ========================================================================= #
  def set_batch(on_which_token = '+')
    _ = @input.split(on_which_token)
    set_name_of_the_element _[0]
    _[1] = '-'+_[1].to_s if on_which_token == '-'
    set_relative_position   _[1]
  end

  # ========================================================================= #
  # === new_position?
  # ========================================================================= #
  def new_position?
    @relative_position
  end

  # ========================================================================= #
  # === report_result
  # ========================================================================= #
  def report_result
    current_position = PERIODIC_TABLE[@name_of_the_element]
    current_position = current_position + new_position?
    opnn; e PERIODIC_TABLE.invert[current_position]+' is at position '+
            sfancy(current_position.to_s)+'.'
  end

  # ========================================================================= #
  # === set_name_of_the_element
  # ========================================================================= #
  def set_name_of_the_element(i = nil)
    # ======================================================================= #
    # if the input is a number, we invert the PERIODIC_TABLE.
    # ======================================================================= #
    if i =~ /^\d+$/
      i = PERIODIC_TABLE.invert[i.to_i]
    end
    @name_of_the_element = i
  end

  # ========================================================================= #
  # === run
  # ========================================================================= #
  def run # (run tag)
    report_result
  end

  # ========================================================================= #
  # === opnn
  # ========================================================================= #
  def opnn
    super(NAMESPACE)
  end

end; end

if __FILE__ == $PROGRAM_NAME
  ChemistryParadise::ShowElement.new(ARGV)
end # show_element 'Xe+5'