#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# require 'chemistry_paradise/toplevel_methods/remove_this_molecule_from.rb'
# =========================================================================== #
require 'chemistry_paradise/split_molecule_names.rb'

module ChemistryParadise

  # ========================================================================= #
  # === ChemistryParadise.remove_this_molecule_from
  #
  # The first argument is the molecule that should be deducted from
  # the formula.
  # ========================================================================= #
  def self.remove_this_molecule_from(
      this_molecule = 'OH',
      from          = 'C2H5NO2'
    )
    array_big_molecule  = ::ChemistryParadise.split_this_molecular_formula_into_a_hash(from)
    array_this_molecule = ::ChemistryParadise.split_this_molecular_formula_into_a_hash(this_molecule)
    # ======================================================================= #
    # Next, iterate over the small molecule.
    # ======================================================================= #
    array_this_molecule.each {|this_compound|
      unless this_compound =~ /\d+/
        this_compound << '1' # Must be at the least one.
      end
      # ===================================================================== #
      # Select the entry that is the correct one.
      # ===================================================================== #
      this_entry = array_big_molecule.find {|entry|
        entry[0,1] == this_compound[0,1]
      }
      begin
        n_times_in_the_big_molecule   = /(\d{1,3})/.match(this_entry)[1].to_i
        n_times_in_the_small_molecule = /(\d{1,3})/.match(this_compound)[1].to_i
        new_n_times = n_times_in_the_big_molecule - n_times_in_the_small_molecule
        new_entry = this_compound[0,1]+new_n_times.to_s
        # ===================================================================== #
        # Now we have the new entry; we need to re-insert it into the big
        # original Array.
        # ===================================================================== #
        proper_index = array_big_molecule.index {|entry|
          entry[0,1] == this_compound[0,1]
        }
        array_big_molecule[proper_index] = new_entry
      rescue NoMethodError => error
        pp error
      end
    }
    return array_big_molecule.join # Join it up again.
  end

end

if __FILE__ == $PROGRAM_NAME
  puts 'Deducting OH from C2H5NO2 next:'
  puts ::ChemistryParadise.remove_this_molecule_from('OH', 'C2H5NO2')  
  puts 'Deducting H2O from C2H5NO2 next:'
  puts ::ChemistryParadise.remove_this_molecule_from('H2O', 'C2H5NO2')
end